<?php

namespace Drupal\Tests\inline_translation\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\UpdatePathTestTrait;
use Drupal\user\Entity\Role;

/**
 * Tests the Inline Translation UI.
 *
 * @group inline_translation
 */
class InlineTranslationUpdateTest extends BrowserTestBase {
  use UpdatePathTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['field_group', 'content_translation'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests that the post update adds the permission to roles.
   */
  public function testPostUpdate(): void {
    $connection = \Drupal::database();
    // Update core.extension.
    $extensions = $connection->select('config')
      ->fields('config', ['data'])
      ->condition('collection', '')
      ->condition('name', 'core.extension')
      ->execute()
      ->fetchField();
    $extensions = unserialize($extensions, ['allowed_classes' => FALSE]);
    $extensions['module']['inline_translation'] = 0;
    $connection->update('config')
      ->fields(['data' => serialize($extensions)])
      ->condition('collection', '')
      ->condition('name', 'core.extension')
      ->execute();

    // Set the schema version.
    $connection->insert('key_value')
      ->fields([
        'collection' => 'system.schema',
        'name' => 'content_lock',
        'value' => 'i:8000;',
      ])
      ->execute();

    $role = Role::load(Role::AUTHENTICATED_ID);
    $this->assertFalse($role->hasPermission('use inline translation'));

    $this->runUpdates();

    $role = Role::load(Role::AUTHENTICATED_ID);
    $this->assertTrue($role->hasPermission('use inline translation'));
    $role = Role::load(Role::ANONYMOUS_ID);
    $this->assertFalse($role->hasPermission('use inline translation'));
  }

}
